Topics

Spirit

# Topic title here

nitely
Esteban Castro Borsani

- 3
- 4h

list

- list item
- list item

list

1. asd
2. qwe

nitely
Esteban Castro Borsani

- 3
- 4h

> > This site is for discussing spirit software in general.

> > A little about Spirit:
> > Spirit was born in Argentina about a year ago. The development was extremely slow until recently, 75% was done in the last three months or so.
> > The design was inspired by Ghost and as you may see it has a bunch of features taken from other forum alternatives.

> > I'm the main developer, and I hope that a lot of people will join me in this journey, maybe you are one of them .

> > Some of the goals for this projects are:

> Tools to encourage conversation.
> Easy integration to preexisting django proyects.
> Clean interface.
> Scalability.
> Easy on resources.
> Test it as much as possible, as you may notice it has over +250 unit tests right now.
> Pythonic code, following the zen of python.

> The official repository can be found at: GitHub
> Issues may be reported here or at the issues tracker

foobar text

nitely
Esteban Castro Borsani

- 17m

start asd qwe asd qwe asd qwe asd qwe asd end

asd qwe

asd qwe

nitely closed this 1 year ago
foobar comment deleted 1 year ago undelete show

texto normal

nitely
Esteban Castro Borsani

Spirit